@@ -17,15 +17,10 @@
 
 package org.apache.jmeter.control;
 
-import java.util.ArrayList;
-import java.util.List;
-
 import org.apache.jmeter.assertions.ResponseAssertion;
 import org.apache.jmeter.junit.JMeterTestCase;
-import org.apache.jmeter.reporters.ResultCollector;
 import org.apache.jmeter.sampler.DebugSampler;
-import org.apache.jmeter.samplers.SampleEvent;
-import org.apache.jmeter.samplers.SampleListener;
+import org.apache.jmeter.test.samplers.CollectSamplesListener;
 import org.apache.jmeter.threads.JMeterContextService;
 import org.apache.jmeter.threads.JMeterThread;
 import org.apache.jmeter.threads.JMeterVariables;
@@ -43,7 +38,7 @@ public class TestTransactionController extends JMeterTestCase {
     public void testIssue57958() throws Exception {
         JMeterContextService.getContext().setVariables(new JMeterVariables());
 
-        TestSampleListener listener = new TestSampleListener();
+        CollectSamplesListener listener = new CollectSamplesListener();
 
         TransactionController transactionController = new TransactionController();
         transactionController.setGenerateParentSample(true);
@@ -80,29 +75,9 @@ public class TestTransactionController extends JMeterTestCase {
         thread.setOnErrorStopThread(true);
         thread.run();
 
-        Assertions.assertEquals(1, listener.events.size(),
+        Assertions.assertEquals(1, listener.getEvents().size(),
                 "Must one transaction samples with parent debug sample");
         Assertions.assertEquals("Number of samples in transaction : 1, number of failing samples : 1",
-                listener.events.get(0).getResult().getResponseMessage());
-    }
-
-    public static class TestSampleListener extends ResultCollector implements SampleListener {
-        private static final long serialVersionUID = -1373192220822942714L;
-        public List<SampleEvent> events = new ArrayList<>();
-
-        @Override
-        public void sampleOccurred(SampleEvent e) {
-            events.add(e);
-        }
-
-        @Override
-        public void sampleStarted(SampleEvent e) {
-            events.add(e);
-        }
-
-        @Override
-        public void sampleStopped(SampleEvent e) {
-            events.add(e);
-        }
+                listener.getEvents().get(0).getResult().getResponseMessage());
     }
 }
